#!/bin/bash

EMEP_FILE="../../EMEP_data/emep_site_data_hourly_2016-2019.csv"
META_DATA_URL="https://uk-air.defra.gov.uk/openair/R_data/AURN_metadata.RData"
META_DATA_FILENAME="AURN_metadata.RData"
OUT_DIR="../AURN_Data_Download/full_aurn_dataset"
INFILE_SUFFIX='2016-2019'
OUTFILE_SUFFIX='2016-2019_imputed'

MINYEARS='1'
USEYEARS='3.5'
DATE_RANGE="2016-01-01_00 2019-12-31_23"


VERBOSE=3

ARGUMENTS_FIXED="--metadata_url ${META_DATA_URL} --date_range ${DATE_RANGE} --min_years ${MINYEARS} 
                 --min_years_ref ${USEYEARS} --metadata_filename ${META_DATA_FILENAME} -o ${OUT_DIR}
                 -s ${INFILE_SUFFIX} --verbose ${VERBOSE}"




run_analysis () 
{


SPECIES_SO2='SO2'
SITES_SO2='BAR3 GRAN LEED MID MY1 PT4 ROCH SCN2 THUR'
#SITES_SO2='BAR3 GRAN LEED'
SITES_SO2='MID LEED MY1 PT4'
STAT_DIR_SO2="aurn_stats/test_stats_SO2"
ARGUMENTS_SO2="--sites ${SITES_SO2} --species ${SPECIES_SO2} --statdir_name ${STAT_DIR_SO2}${SCEN_TAIL}"


SPECIES_O3='O3'
SITES_O3='CANT LERW MAN3 WIG5 CWMB MID ABD COAL PT4 MY1 CLL2 MAHG PMTH SV LH BORN PEMB 
          LECU ESK SUN2 KC1 LN HRL NOTT AH ED3 GLKP OSY HM BAR3 WFEN SHDG YW NO12 TRAN 
          LEED WAL4 NEWC AGRN LON6 BRT3 WEYB BEL2 SIB LEAM ACTH BLC2 PLYM PEEB STOK CHBO 
          HG4 PRES HUL2 FW SEND LVP HIL'
#SITES_O3='ESK SUN2 KC1 LN'
SITES_O3='MID LEED MY1 PT4'
STAT_DIR_O3="aurn_stats_quantile/test_stats_O3"
ARGUMENTS_O3="--sites ${SITES_O3} --species ${SPECIES_O3} --statdir_name ${STAT_DIR_O3}${SCEN_TAIL}"


SPECIES_PM10='PM10'
SITES_PM10='LEAM NOTT GLKP MID LED6 LEIR ABD MY1 LVP CA1 LEED YK10 CHP GRAN STKR KC1 
            BEL1 THUR BURW SHDG CLL2 SWA1 PLYM HRL NEWC PT4 GHSR CHAT ROCH'
#SITES_PM10='BURW SHDG CLL2 SWA1'
SITES_PM10='MID LEED MY1 PT4'
STAT_DIR_PM10="aurn_stats/test_stats_PM10"
ARGUMENTS_PM10="--sites ${SITES_PM10} --species ${SPECIES_PM10} --statdir_name ${STAT_DIR_PM10}${SCEN_TAIL}"


SPECIES_PM25='PM2.5'
SITES_PM25='ED3 ABD ACTH BEL2 KC1 MID LEED CA1 GHSR TRAN LED6 EAGL SWA1 HRL LECU LEAM
            CLL2 HUL2 CHLG NOTT PRES SHDG CHS7 GLKP GRAN ROCH COAL NEWC STOK PT4 MY1 
            AGRN CHBO LVP'
#SITES_PM25='CHLG NOTT PRES SHDG'
SITES_PM25='MID LEED MY1 PT4'
STAT_DIR_PM25="aurn_stats/test_stats_PM2.5"
ARGUMENTS_PM25="--sites ${SITES_PM25} --species ${SPECIES_PM25} --statdir_name ${STAT_DIR_PM25}${SCEN_TAIL}"


SPECIES_NO2='NO2'
SITES_NO2='ABD ABD7 ABD8 AGRN ARM6 BAR3 BDMA BEL1 BEX BIL BLC2 BORN BRT3 BURW 
                BUSH CA1 CAE6 CAM CANT CHAT CHP CHS7 CLL2 COAL CW CWMB DCST DUMF EAGL 
                ECCL ESK EX FW GGWR GHSR GLA4 GLKP GRAN HG1 HG4 HIL HONI HOPE HORE HRL 
                HUL2 HULR INV2 KC1 LB LEAM LEAR LECU LED6 LEED LEIR LH LIN3 LON6 LUTR 
                LVP MACK MAHG MAN3 MID MY1 NEWC NO12 NOTT OSY OX PEEB PLYM PMTH PRES 
                PT4 ROCH SA33 SCN2 SDY SHDG SHE SOTR STKR STOK STOR SUN2 SWA1 TH2 THUR 
                TRAN WAL4 WAR WIG5 YK11 YW'
#SITES_NO2='MAHG MAN3 MID MY1'
SITES_NO2='MID LEED MY1 PT4'
STAT_DIR_NO2="aurn_stats/test_stats_NO2"
ARGUMENTS_NO2="--sites ${SITES_NO2} --species ${SPECIES_NO2} --statdir_name ${STAT_DIR_NO2}${SCEN_TAIL}"


SPECIES_NOXasNO2='NOXasNO2'
SITES_NOXasNO2='ABD ABD7 ABD8 AGRN ARM6 BAR3 BDMA BEL1 BEX BIL BLC2 BORN BRT3 BURW 
                BUSH CA1 CAE6 CAM CANT CHAT CHP CHS7 CLL2 COAL CW CWMB DCST DUMF EAGL 
                ECCL ESK EX FW GGWR GHSR GLA4 GLKP GRAN HG1 HG4 HIL HONI HOPE HORE HRL 
                HUL2 HULR INV2 KC1 LB LEAM LEAR LECU LED6 LEED LEIR LH LIN3 LON6 LUTR 
                LVP MACK MAHG MAN3 MID MY1 NEWC NO12 NOTT OSY OX PEEB PLYM PMTH PRES 
                PT4 ROCH SA33 SCN2 SDY SHDG SHE SOTR STKR STOK STOR SUN2 SWA1 TH2 THUR 
                TRAN WAL4 WAR WIG5 YK11 YW'
#SITES_NOXasNO2='HULR INV2 KC1 LB'
SITES_NOXasNO2='MID LEED MY1 PT4'
STAT_DIR_NOXasNO2="aurn_stats/test_stats_NOXasNO2"
ARGUMENTS_NOXasNO2="--sites ${SITES_NOXasNO2} --species ${SPECIES_NOXasNO2} --statdir_name ${STAT_DIR_NOXasNO2}${SCEN_TAIL}"

SPECIES_COMBINED='O3 NO2 NOXasNO2 PM2.5 PM10'
SITES_COMBINED='NEWC ABD LEED LVP PT4 NOTT HRL MY1 CLL2 SHDG LEAM MID KC1 GLKP'
SITES_COMBINED='LEED LVP PT4 NOTT'
STAT_DIR_COMBINED="aurn_stats/test_stats_combined"
ARGUMENTS_COMBINED="--sites ${SITES_COMBINED} --species ${SPECIES_COMBINED} --statdir_name ${STAT_DIR_COMBINED}${SCEN_TAIL}"

SPECIES_COMBINED_SO2='O3 NO2 NOXasNO2 PM2.5 PM10 SO2'
SITES_COMBINED_SO2='MID LEED MY1 PT4'
STAT_DIR_COMBINED_SO2="aurn_stats/test_stats_combined_and_so2"
ARGUMENTS_COMBINED_SO2="--sites ${SITES_COMBINED_SO2} --species ${SPECIES_COMBINED_SO2} --statdir_name ${STAT_DIR_COMBINED_SO2}${SCEN_TAIL}"



python AURN_impute_testing.py ${ARGUMENTS_FIXED} ${ARGUMENTS_DATA} ${ARGUMENTS_SO2}
python AURN_impute_testing.py ${ARGUMENTS_FIXED} ${ARGUMENTS_DATA} ${ARGUMENTS_O3}
python AURN_impute_testing.py ${ARGUMENTS_FIXED} ${ARGUMENTS_DATA} ${ARGUMENTS_NO2} 
python AURN_impute_testing.py ${ARGUMENTS_FIXED} ${ARGUMENTS_DATA} ${ARGUMENTS_NOXasNO2}
python AURN_impute_testing.py ${ARGUMENTS_FIXED} ${ARGUMENTS_DATA} ${ARGUMENTS_PM10}
python AURN_impute_testing.py ${ARGUMENTS_FIXED} ${ARGUMENTS_DATA} ${ARGUMENTS_PM25} 
python AURN_impute_testing.py ${ARGUMENTS_FIXED} ${ARGUMENTS_DATA} ${ARGUMENTS_COMBINED} 
python AURN_impute_testing.py ${ARGUMENTS_FIXED} ${ARGUMENTS_DATA} ${ARGUMENTS_COMBINED_SO2}
#"--check_sites"
}

### base setup
DATA_LOSS_POS='random'
DATA_LOST='0.5'
ARGUMENTS_DATA="--data_loss_position ${DATA_LOSS_POS} --data_lost ${DATA_LOST}"
SCEN_TAIL="_random"
run_analysis

### with EMEP data
DATA_LOSS_POS='random'
DATA_LOST='0.5'
ARGUMENTS_DATA="--data_loss_position ${DATA_LOSS_POS} --data_lost ${DATA_LOST} --emep_filename ${EMEP_FILE}"
SCEN_TAIL="_random_with_EMEP"
run_analysis

### with 1/2 data loss at start of period
DATA_LOSS_POS='start'
DATA_LOST='0.5'
ARGUMENTS_DATA="--data_loss_position ${DATA_LOSS_POS} --data_lost ${DATA_LOST}"
SCEN_TAIL="_startloss"
run_analysis

### with EMEP data and 1/2 data loss at start of period
DATA_LOSS_POS='start'
DATA_LOST='0.5'
ARGUMENTS_DATA="--data_loss_position ${DATA_LOSS_POS} --data_lost ${DATA_LOST} --emep_filename ${EMEP_FILE}"
SCEN_TAIL="_startloss_with_EMEP"
run_analysis



### with 3/4 data loss at start of period
DATA_LOSS_POS='start'
DATA_LOST='0.75'
ARGUMENTS_DATA="--data_loss_position ${DATA_LOSS_POS} --data_lost ${DATA_LOST}"
SCEN_TAIL="_startloss0.75"
run_analysis

### with EMEP data and 3/4 data loss at start of period
DATA_LOSS_POS='start'
DATA_LOST='0.75'
ARGUMENTS_DATA="--data_loss_position ${DATA_LOSS_POS} --data_lost ${DATA_LOST} --emep_filename ${EMEP_FILE}"
SCEN_TAIL="_startloss0.75_with_EMEP"
run_analysis

### with 1/4 data loss at start of period
DATA_LOSS_POS='start'
DATA_LOST='0.25'
ARGUMENTS_DATA="--data_loss_position ${DATA_LOSS_POS} --data_lost ${DATA_LOST}"
SCEN_TAIL="_startloss0.25"
run_analysis

### with EMEP data and 1/4 data loss at start of period
DATA_LOSS_POS='start'
DATA_LOST='0.25'
ARGUMENTS_DATA="--data_loss_position ${DATA_LOSS_POS} --data_lost ${DATA_LOST} --emep_filename ${EMEP_FILE}"
SCEN_TAIL="_startloss0.25_with_EMEP"
run_analysis
